Replace underscores with dashes in fsck command line options.
[osl.git] / osl.c
diff --git a/osl.c b/osl.c
index a9dcc29bd48790ff93d54027aa2052bc373c6373..5a0dde80ea6eb623172caa2f538834cf12b0a01b 100644 (file)
--- a/osl.c
+++ b/osl.c
@@ -331,8 +331,8 @@ err:
  * \param map The memory mapping of the index file.
  * \param desc The values found in the index header are returned here.
  *
  * \param map The memory mapping of the index file.
  * \param desc The values found in the index header are returned here.
  *
* Read the index header, check for the paraslash magic string and the table version number.
* Read all information stored in the index header into \a desc.
  *
  * \return Standard.
  *
  *
  * \return Standard.
  *
@@ -349,7 +349,7 @@ int read_table_desc(struct osl_object *map, struct osl_table_description *desc)
 
        if (map->size < MIN_INDEX_HEADER_SIZE(1))
                return -E_OSL_SHORT_TABLE;
 
        if (map->size < MIN_INDEX_HEADER_SIZE(1))
                return -E_OSL_SHORT_TABLE;
-       if (strncmp(buf + IDX_PARA_MAGIC, PARA_MAGIC, strlen(PARA_MAGIC)))
+       if (strncmp(buf + IDX_OSL_MAGIC, OSL_MAGIC, strlen(OSL_MAGIC)))
                return -E_OSL_NO_MAGIC;
        version = read_u8(buf + IDX_VERSION);
        if (version < MIN_TABLE_VERSION || version > MAX_TABLE_VERSION)
                return -E_OSL_NO_MAGIC;
        version = read_u8(buf + IDX_VERSION);
        if (version < MIN_TABLE_VERSION || version > MAX_TABLE_VERSION)
@@ -484,7 +484,7 @@ static int create_table_index(struct osl_table *t)
        buf = calloc(1, size);
        if (!buf)
                return -E_OSL_NOMEM;
        buf = calloc(1, size);
        if (!buf)
                return -E_OSL_NOMEM;
-       sprintf(buf + IDX_PARA_MAGIC, "%s", PARA_MAGIC);
+       sprintf(buf + IDX_OSL_MAGIC, "%s", OSL_MAGIC);
        write_u8(buf + IDX_TABLE_FLAGS, t->desc->flags);
        write_u8(buf + IDX_DIRTY_FLAG, 0);
        write_u8(buf + IDX_VERSION, CURRENT_TABLE_VERSION);
@@ -331,8 +331,8 @@ err:
  * \param desc The values found in the index header are returned here.
  *
- * Read the index header, check for the paraslash magic string and the table version number.
- * Read all information stored in the index header into \a desc.
+ * Read the index header, check for the osl magic string and the table version
+ * number.  Read all information stored in the index header into \a desc.
  *
  * \return Standard.
        write_u8(buf + IDX_TABLE_FLAGS, t->desc->flags);
        write_u8(buf + IDX_DIRTY_FLAG, 0);
        write_u8(buf + IDX_VERSION, CURRENT_TABLE_VERSION);